@@ -7,7 +7,7 @@ from django.forms import ModelForm
 from django.forms.fields import CharField, ChoiceField, BooleanField
 from django.forms.models import ModelMultipleChoiceField
 from django.forms.widgets import CheckboxInput
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from .models import PermafrostRole, get_optional_by_category, get_choices
 
 CHOICES = [('', _("Choose Role Type"))] + get_choices()
