@@ -63,7 +63,7 @@ class Command(BaseCommand):
         key_order = list(data.keys())
         key_order.sort()
 
-        print("from django.utils.translation import ugettext_lazy as _\n")
+        print("from django.utils.translation import gettext_lazy as _\n")
 
         print("PERMAFROST_CATEGORIES = {")
 
