@@ -298,9 +298,10 @@ class PermafrostViewTests(TestCase):
 
     def setUp(self):
         self.client = Client()
-        self.pf_role = PermafrostRole.objects.create(category="staff", name="Test Role")
-        super_user = get_user_model().objects.get(pk=1)
-        self.client.force_login(super_user)
+        self.pf_role = PermafrostRole.objects.create(category="staff", name="Test Role", site=Site.objects.get_current())
+        PermafrostRole.objects.create(category="staff", name="Test Role", site=Site.objects.get(pk=2))
+        self.super_user = get_user_model().objects.get(pk=1)
+        self.client.force_login(self.super_user)
 
     def test_permafrost_base_url_resolves(self):
         found = resolve("/permafrost/")
@@ -328,13 +329,14 @@ class PermafrostViewTests(TestCase):
 
     def test_permafrostrole_manage_template_displays_list_of_roles_on_site(self):
         uri = reverse('permafrost:roles-manage')
+        import html
         response = self.client.get(uri)
         objects = PermafrostRole.on_site.all()
         
         self.assertTrue(len(objects))
         
         for object in objects:
-            self.assertContains(response, f'{object}')
+            self.assertContains(response, html.escape(f'{object}'))
     
     def test_permafrostrole_manage_template_displays_selected_role_details(self):
         uri = reverse('permafrost:roles-manage')
@@ -504,6 +506,19 @@ class PermafrostViewTests(TestCase):
         updated_role = PermafrostRole.objects.get(pk=self.pf_role.pk)
         self.assertEqual(updated_role.name, "Test Change")
     
+    def test_role_update_POST_updates_when_no_values_are_changed(self):
+        uri = reverse('permafrost:role-update', kwargs={'slug': 'test-role'})
+       
+        request = RequestFactory().post(uri, data={'name': 'Test Role'}, follow=True)
+
+        request.user = self.super_user
+        request.site = Site.objects.get(pk=2)
+        response = PermafrostRoleUpdateView.as_view()(request, slug='test-role')
+        response.client = self.client
+        self.assertRedirects(response, '/permafrost/role/test-role/')
+        updated_role = PermafrostRole.objects.get(pk=self.pf_role.pk)
+
+    
     def test_optional_permissions_are_updated_on_POST(self):
         ## ensure role currently has no optional permissions
         allowed_optional_permission_ids =[permission.id for permission in self.pf_role.optional_permissions()]
@@ -552,7 +567,6 @@ class PermafrostViewTests(TestCase):
         response = self.client.post(uri, data=data, follow=True)
         
         updated_permission_ids = [permission.id for permission in self.pf_role.permissions().all() if permission.id in allowed_optional_permission_ids]
-        
         try:
             self.assertEqual(updated_permission_ids, [])
         except:
@@ -570,11 +584,11 @@ class PermafrostViewTests(TestCase):
         response = self.client.post(uri, data=data, follow=True)
         
         try:
-            updated_role = PermafrostRole.objects.get(slug=self.pf_role.slug)
+            updated_role = PermafrostRole.objects.get(slug=self.pf_role.slug, site__id=1)
             self.assertEqual(updated_role.deleted, True)
         except:
             print("")
-            print(model_to_dict(PermafrostRole.objects.get(slug=self.pf_role.slug)))
+            print(model_to_dict(PermafrostRole.objects.get(slug=self.pf_role.slug, site__id=1)))
             print("")
             raise
     
@@ -665,3 +679,25 @@ class PermafrostSiteMixinTests(TestCase):
         request.site = Site.objects.get(pk=1)
 
         self.assertRaises(PermissionDenied, PermafrostRoleListView.as_view(), request)
+    
+    def test_multiple_roles_with_shared_permissions(self):
+        """
+        Both Role id 9 and 12 share a single permission: 4: view_permafrostrole
+        """
+        request = self.factory.get('/manage/')
+        request.user = self.user
+        request.site = Site.objects.get(pk=1)
+
+        # add to site 2 Administrator role
+        bobs_staff_role = PermafrostRole.objects.get(pk=4)
+        bobs_staff_role.users_add(self.user)
+
+        response = PermafrostRoleListView.as_view()(request)
+
+        self.assertEqual(response.status_code, 200)
+
+        councilor_staff_role = PermafrostRole.objects.get(pk=2)
+        councilor_staff_role.users_add(self.user)
+        response = PermafrostRoleListView.as_view()(request)
+
+        self.assertEqual(response.status_code, 200)  
\ No newline at end of file
